@@ -30,7 +30,7 @@ def test_invalid_id():
     result = runner.invoke(app, ["1002"])
     assert result.exit_code != 0
     assert (
-        'Error: Invalid value for "ID": 1002 is not in the valid range of 0 to 1000.'
+        "Error: Invalid value for 'ID': 1002 is not in the valid range of 0 to 1000."
         in result.output
     )
 
@@ -39,7 +39,7 @@ def test_invalid_age():
     result = runner.invoke(app, ["5", "--age", "15"])
     assert result.exit_code != 0
     assert (
-        'Error: Invalid value for "--age": 15 is smaller than the minimum valid value 18.'
+        "Error: Invalid value for '--age': 15 is smaller than the minimum valid value 18."
         in result.output
     )
 
@@ -48,7 +48,7 @@ def test_invalid_score():
     result = runner.invoke(app, ["5", "--age", "20", "--score", "100.5"])
     assert result.exit_code != 0
     assert (
-        'Error: Invalid value for "--score": 100.5 is bigger than the maximum valid value 100.'
+        "Error: Invalid value for '--score': 100.5 is bigger than the maximum valid value 100."
         in result.output
     )
 
